@@ -1,11 +1,12 @@
 use strictures 1;
 package Mojito::Collection::CRUD::Mongo;
 {
-  $Mojito::Collection::CRUD::Mongo::VERSION = '0.19';
+  $Mojito::Collection::CRUD::Mongo::VERSION = '0.20';
 }
 use MongoDB::OID;
 use 5.010;
 use Moo;
+use Syntax::Keyword::Junction qw/ any /;
 use Data::Dumper::Concise;
 
 with('Mojito::Role::DB::Mongo');
@@ -108,6 +109,29 @@ sub get_all {
     return $self->collection->find;
 }
 
+=head2 collection_for_page
+
+Get all the collection ids for which this page is a member of.
+
+=cut
+
+sub collections_for_page {
+    my ($self, $page_id) = @_;
+
+    # NOTE: For some yet to be determined reason I could not
+    # pass {collected_page_ids => $page_id} to $self->collection->find();
+    my $collections = $self->get_all; 
+    my @collection_ids;
+    while (my $doc = $collections->next) {
+        my @collected_pages = @{$doc->{collected_page_ids}};
+        if ($page_id eq any(@collected_pages)) {
+            push @collection_ids, $doc->{_id}->value ;
+        }
+    }
+
+    return @collection_ids;
+}
+
 =head2 BUILD
 
 Set the collection we want to work with.
