@@ -1,11 +1,12 @@
 use strictures 1;
 package Mojito::Middleware;
 {
-  $Mojito::Middleware::VERSION = '0.19';
+  $Mojito::Middleware::VERSION = '0.20';
 }
 use parent qw(Plack::Middleware);
 use Plack::Util::Accessor qw/config/;
 use Mojito;
+use DateTime::TimeZone;
 
 =head1 Name
 
@@ -24,6 +25,7 @@ sub call {
     $config->{base_url} = $base_url;
     my @my_env = qw/REMOTE_USER PATH_INFO URI_REQUEST HTTP_REFERER HTTP_HOST/;
     @{$config}{qw/username PATH_INFO URI_REQUEST HTTP_REFERER HTTP_HOST/} = @{$env}{@my_env};
+    $config->{local_timezone} ||= DateTime::TimeZone->new(name => 'local')->name;
     # TODO?: Just use a hash instead of an object
     $env->{"mojito"} = Mojito->new( 
         base_url    => $base_url, 
