@@ -1,7 +1,7 @@
 use strictures 1;
 package Mojito::Template;
 {
-  $Mojito::Template::VERSION = '0.19';
+  $Mojito::Template::VERSION = '0.20';
 }
 use Moo;
 use 5.010;
@@ -9,8 +9,9 @@ use MooX::Types::MooseLike::Base qw(:all);
 use Mojito::Model::Link;
 use Mojito::Collection::CRUD;
 use Mojito::Page::Publish;
-use Data::Dumper::Concise;
 use DateTime;
+use Syntax::Keyword::Junction qw/ any /;
+use Data::Dumper::Concise;
 
 with('Mojito::Template::Role::Javascript');
 with('Mojito::Template::Role::CSS');
@@ -48,10 +49,18 @@ has linker => (
         sort_collection_pages_view   => 'view_sortable_page_list',
         collections_index_view       => 'view_collections_index',
         get_docs_for_month           => 'get_docs_for_month',
+        get_collection_list         => 'get_collections_index_link_data',
     },
     writer => '_set_linker',
 );
 
+has collector => (
+    is      => 'ro',
+    isa     => sub { die "Need a Collection::CRUD object" unless $_[0]->isa('Mojito::Collection::CRUD') },
+    'default' => sub { my $self = shift; return Mojito::Collection::CRUD->new(config => $self->config, db => $self->db) },
+    lazy => 1,
+);
+
 has 'home_page' => (
     is      => 'rw',
     lazy    => 1,
@@ -105,6 +114,20 @@ sub _build_template {
     my $publisher = Mojito::Page::Publish->new(config => $self->config);
     my $publish_form = '';
     $publish_form = $publisher->publish_form||'' if $page_id;
+    my @collections_for_page = $self->collector->editer->collections_for_page($page_id);
+    my $collection_list = $self->get_collection_list||[];
+    my $collection_size = scalar @{$collection_list} + 1;
+    my $collection_options = "<select id='collection_select' name='collection_select' 
+    multiple='multiple' size='${collection_size}' form='editForm' style='font-size: 1.00em; display:none;' >\n";
+    $collection_options .= "<option value='0'>- No Collection -</option>\n";
+    foreach my $collection (@{$collection_list}) {
+        $collection_options .= "<option value='$collection->{id}'";
+        if ($collection->{id} eq any(@collections_for_page)) {
+            $collection_options .= " selected='selected' ";
+        }
+        $collection_options .= ">$collection->{title}</option>\n";
+    }
+    $collection_options .= "</select>\n";
     my $edit_page = <<"END_HTML";
 <!doctype html>
 <html>
@@ -126,6 +149,13 @@ $js_css
 <article id="body_wrapper">
 <input type="hidden" id ="page_id" name="page_id" value="$page_id" />
 <section id="edit_area">
+<span style="font-size: 0.82em;"><label id="feeds_label">feeds+</label>
+  <input id="feeds" name="feeds" form="editForm" value="" size="12" style="font-size: 1.00em; display:none;" />
+</span>
+<span style="font-size: 0.82em;">
+<label id="collection_label">collections+</label>
+$collection_options
+</span>
 <form id="editForm" action="" accept-charset="UTF-8" method="post">
     <div id="wiki_language">
         $wiki_language_selection
@@ -137,6 +167,10 @@ $js_css
     <input id="commit_message" name="commit_message" value="commit message" onclick="this.value == 'commit message' ? this.value = '' : true"/>
     <input id="submit_save" name="submit" type="submit" value="Save" style="font-size: 66.7%;" />
     <input id="submit_view" name="submit" type="submit" value="Done" style="font-size: 66.7%;" />
+    <label style="font-size: 0.667em;" for="public" title="Check if you want a publicly viewable page" >
+      <input id="public" name="public" value="1" type="checkbox" style="font-size: 0.667em;" />
+       public
+    </label>
 </form>
 </section>
 <section id="view_area" class="view_area_edit_mode"></section>
@@ -354,15 +388,29 @@ sub fillin_edit_page {
 
     my $page_source   = $page->{page_source}; 
     my $wiki_language = $page->{default_format}; 
-    my $page_title   = $page->{title}||'no title'; 
+    my $page_title    = $page->{title}||'no title';
+    my @feeds = ();
+    if (ref($page->{feeds}) eq 'ARRAY') {
+        @feeds = @{$page->{feeds}}; 
+    }
+    my $feeds         = join ':', @feeds;
+    my $public        = $page->{public};
 
+    # Set page_id for the template
+    $self->page_id($mongo_id);
     my $output   = $self->template;
     my $base_url = $self->base_url;
     $output =~
 s/<script><\/script>/<script>mojito.preview_url = '${base_url}preview';<\/script>/s;
+    # Set some form values
     $output =~ s/(<input id="mongo_id".*?value=)""/$1"${mongo_id}"/si;
+#    $output =~ s/(<input .*? id ="page_id" .*? value=)""/$1"${mongo_id}"/si;
     $output =~ s/(<input id="wiki_language".*?value=)""/$1"${wiki_language}"/si;
     $output =~ s/(<input id="page_title".*?value=)""/$1"${page_title}"/si;
+    $output =~ s/(<input id="feeds".*?value=)""/$1"${feeds}"/si;
+    if ($public) {
+        $output =~ s/(<input id="public")/$1 checked="checked"/si;
+    }
     $output =~
 s/(<textarea\s+id="content"[^>]*>)<\/textarea>/$1${page_source}<\/textarea>/si;
     $output =~
@@ -388,8 +436,7 @@ s/(<section\s+id="view_area"[^>]*>)<\/section>/$1${page_view}<\/section>/si;
     if ($page_title) {
        $output =~ s/<title>.*?<\/title>/<title>${page_title}<\/title>/si;
     }
-
-    return $output;
+    return $output; 
 }
 
 =head2 fillin_create_page
